pub struct TaskCreatedResponse {
pub task_id: String,
pub status: String,
pub kind: String,
pub monitor_command: String,
pub poll_command: String,
pub cancel_command: String,
pub hint: String,
}Expand description
Returned by tools that schedule a background task.
Fields
task_id: Stringstatus: Stringkind: Stringmonitor_command: Stringpoll_command: Stringcancel_command: Stringhint: StringTrait Implementations
Sourceimpl Clone for TaskCreatedResponse
impl Clone for TaskCreatedResponse
Sourcefn clone(&self) -> TaskCreatedResponse
fn clone(&self) -> TaskCreatedResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskCreatedResponse
impl Debug for TaskCreatedResponse
Sourceimpl<'de> Deserialize<'de> for TaskCreatedResponse
impl<'de> Deserialize<'de> for TaskCreatedResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskCreatedResponse
impl JsonSchema for TaskCreatedResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskCreatedResponse
impl RefUnwindSafe for TaskCreatedResponse
impl Send for TaskCreatedResponse
impl Sync for TaskCreatedResponse
impl Unpin for TaskCreatedResponse
impl UnsafeUnpin for TaskCreatedResponse
impl UnwindSafe for TaskCreatedResponse