pub struct BatchFetchArgs {
pub urls: Vec<String>,
pub force_refresh: bool,
pub concurrency: Option<u32>,
pub per_domain_concurrency: Option<u32>,
}Expand description
Wire-side batch_fetch tool arguments.
Fields
urls: Vec<String>force_refresh: boolconcurrency: Option<u32>per_domain_concurrency: Option<u32>Trait Implementations
Sourceimpl Clone for BatchFetchArgs
impl Clone for BatchFetchArgs
Sourcefn clone(&self) -> BatchFetchArgs
fn clone(&self) -> BatchFetchArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchFetchArgs
impl Debug for BatchFetchArgs
Sourceimpl Default for BatchFetchArgs
impl Default for BatchFetchArgs
Sourcefn default() -> BatchFetchArgs
fn default() -> BatchFetchArgs
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BatchFetchArgs
impl<'de> Deserialize<'de> for BatchFetchArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BatchFetchArgs
impl JsonSchema for BatchFetchArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BatchFetchArgs
impl RefUnwindSafe for BatchFetchArgs
impl Send for BatchFetchArgs
impl Sync for BatchFetchArgs
impl Unpin for BatchFetchArgs
impl UnsafeUnpin for BatchFetchArgs
impl UnwindSafe for BatchFetchArgs